searchData={"items":[{"type":"module","title":"TypeResolver","doc":"Type resolver is a library to resolve spec-types at compile time.\nThat is, reducing the specs to only native types by resolving user-defined,\nbuilt-in and remote types. The result is a type expressed in easy to\nhandle structs of types.","ref":"TypeResolver.html"},{"type":"module","title":"Rational - TypeResolver","doc":"Often times we want to analyse spec-types in macros and derive functionality\nfrom these types. Analysing and working with AST from `Code.Typespec` or\nErlang AST is challenging and cumbersome. Furthermore, there is no\nstandalone library that resolves user-defined types, built-in types and\nremote-types. This library fills this gap.","ref":"TypeResolver.html#module-rational"},{"type":"module","title":"Usage - TypeResolver","doc":"The library offers the macro `TypeResolver.resolve/1` that can be used\nas follows:\n\n    resolve(integer() | String.t())\n\nIt returns the following representation:\n\n    %TypeResolver.UnionT{\n      inner: [%TypeResolver.Types.IntegerT{}, %TypeResolver.Types.BinaryT{}]\n    }","ref":"TypeResolver.html#module-usage"},{"type":"module","title":"Type exporter - TypeResolver","doc":"To resolve remote types, we rely on `Code.Typespec.fetch_types/1`. For\nthis function to work, the module has to be compiled into a beam file,\nwhich cannot always be ensured at macro expansion time.\n\nTo handle this problem, we provide the module `TypeResolver.TypeExporter`.\nThis module takes care of types being exported and makes them available\nat macro expansion time. The module has to be used in the remote module\nthat contains the type, as follows: \n\n    defmodule MyRemoteModule do \n      use TypeResolver.TypeExporter\n\n      @type my_remote_t :: ...\n    end","ref":"TypeResolver.html#module-type-exporter"},{"type":"module","title":"Limitations - TypeResolver","doc":"- Currently this library cannot handle recursive types and does not detect\n  them. When using recursive times, compilation will be stuck in an infinite\n  recursion.\n- Struct types don't get their member resolved","ref":"TypeResolver.html#module-limitations"},{"type":"macro","title":"TypeResolver.resolve/1","doc":"This marco takes a spec expression and returns a struct-based representation\nof the types, resolved to only basic spec-types, e.g:\n\n    resolve(integer() | String.t())\n\nreturns the following representation:\n\n    %TypeResolver.UnionT{\n      inner: [%TypeResolver.Types.IntegerT{}, %TypeResolver.Types.BinaryT{}]\n    }\n\nRaises if types cannot be resolved.","ref":"TypeResolver.html#resolve/1"},{"type":"type","title":"TypeResolver.ast_t/0","doc":"","ref":"TypeResolver.html#t:ast_t/0"},{"type":"module","title":"TypeResolver.Env","doc":"This module defines the environment that is used to\nresolve types.\n\nIt consists of the following:\n\n- a target module the currently resolved types resides in\n- a lookup of user types of the current module\n- maybe the args for current the type","ref":"TypeResolver.Env.html"},{"type":"function","title":"TypeResolver.Env.clear_user_types/1","doc":"","ref":"TypeResolver.Env.html#clear_user_types/1"},{"type":"function","title":"TypeResolver.Env.get_user_type/2","doc":"","ref":"TypeResolver.Env.html#get_user_type/2"},{"type":"function","title":"TypeResolver.Env.make/2","doc":"","ref":"TypeResolver.Env.html#make/2"},{"type":"function","title":"TypeResolver.Env.with_args/2","doc":"","ref":"TypeResolver.Env.html#with_args/2"},{"type":"function","title":"TypeResolver.Env.with_target_module/2","doc":"","ref":"TypeResolver.Env.html#with_target_module/2"},{"type":"function","title":"TypeResolver.Env.with_user_types/2","doc":"","ref":"TypeResolver.Env.html#with_user_types/2"},{"type":"type","title":"TypeResolver.Env.t/0","doc":"","ref":"TypeResolver.Env.html#t:t/0"},{"type":"module","title":"TypeResolver.ParseHelpers","doc":"","ref":"TypeResolver.ParseHelpers.html"},{"type":"function","title":"TypeResolver.ParseHelpers.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.html#parse/2"},{"type":"function","title":"TypeResolver.ParseHelpers.parse_args/2","doc":"","ref":"TypeResolver.ParseHelpers.html#parse_args/2"},{"type":"function","title":"TypeResolver.ParseHelpers.parse_user_type/1","doc":"","ref":"TypeResolver.ParseHelpers.html#parse_user_type/1"},{"type":"function","title":"TypeResolver.ParseHelpers.parse_user_types/1","doc":"","ref":"TypeResolver.ParseHelpers.html#parse_user_types/1"},{"type":"function","title":"TypeResolver.ParseHelpers.prepare_args/2","doc":"","ref":"TypeResolver.ParseHelpers.html#prepare_args/2"},{"type":"function","title":"TypeResolver.ParseHelpers.resolve/3","doc":"","ref":"TypeResolver.ParseHelpers.html#resolve/3"},{"type":"module","title":"TypeResolver.ParseHelpers.AnnotatedType","doc":"","ref":"TypeResolver.ParseHelpers.AnnotatedType.html"},{"type":"function","title":"TypeResolver.ParseHelpers.AnnotatedType.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.AnnotatedType.html#parse/2"},{"type":"module","title":"TypeResolver.ParseHelpers.Literals","doc":"","ref":"TypeResolver.ParseHelpers.Literals.html"},{"type":"function","title":"TypeResolver.ParseHelpers.Literals.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.Literals.html#parse/2"},{"type":"module","title":"TypeResolver.ParseHelpers.Literals.InternalOptional","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalOptional.html"},{"type":"type","title":"TypeResolver.ParseHelpers.Literals.InternalOptional.t/0","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalOptional.html#t:t/0"},{"type":"module","title":"TypeResolver.ParseHelpers.Literals.InternalRequired","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalRequired.html"},{"type":"type","title":"TypeResolver.ParseHelpers.Literals.InternalRequired.t/0","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalRequired.html#t:t/0"},{"type":"module","title":"TypeResolver.ParseHelpers.Literals.InternalStruct","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalStruct.html"},{"type":"type","title":"TypeResolver.ParseHelpers.Literals.InternalStruct.t/0","doc":"","ref":"TypeResolver.ParseHelpers.Literals.InternalStruct.html#t:t/0"},{"type":"module","title":"TypeResolver.ParseHelpers.ParametrizedType","doc":"","ref":"TypeResolver.ParseHelpers.ParametrizedType.html"},{"type":"function","title":"TypeResolver.ParseHelpers.ParametrizedType.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.ParametrizedType.html#parse/2"},{"type":"module","title":"TypeResolver.ParseHelpers.RemoteTypes","doc":"","ref":"TypeResolver.ParseHelpers.RemoteTypes.html"},{"type":"function","title":"TypeResolver.ParseHelpers.RemoteTypes.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.RemoteTypes.html#parse/2"},{"type":"function","title":"TypeResolver.ParseHelpers.RemoteTypes.parse_user_defined/2","doc":"","ref":"TypeResolver.ParseHelpers.RemoteTypes.html#parse_user_defined/2"},{"type":"module","title":"TypeResolver.ParseHelpers.SimpleType","doc":"","ref":"TypeResolver.ParseHelpers.SimpleType.html"},{"type":"function","title":"TypeResolver.ParseHelpers.SimpleType.parse/1","doc":"","ref":"TypeResolver.ParseHelpers.SimpleType.html#parse/1"},{"type":"module","title":"TypeResolver.ParseHelpers.UserTypes","doc":"","ref":"TypeResolver.ParseHelpers.UserTypes.html"},{"type":"function","title":"TypeResolver.ParseHelpers.UserTypes.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.UserTypes.html#parse/2"},{"type":"module","title":"TypeResolver.ParseHelpers.Vars","doc":"","ref":"TypeResolver.ParseHelpers.Vars.html"},{"type":"function","title":"TypeResolver.ParseHelpers.Vars.parse/2","doc":"","ref":"TypeResolver.ParseHelpers.Vars.html#parse/2"},{"type":"module","title":"TypeResolver.TypeExporter","doc":"A module to export types to a submodule called __MODULE__.ExportedTypes.\n\nThe generated module contains a functions `types` that returns all\ntypes of __MODULE__ as returned by `Code.Typespec.fetch_types/1`.\n\nUse this module to expose types of your module to be used with this library.\nDirectly calling `Code.Typespec.fetch_types/1` onto the modules often\nreturns errors, since it may have no beam file at the time.\n\nTo use this module, call the use-Macro:\n\n    defmodule MyModule do\n      use TypeExporter\n\n      # module code ...\n    end","ref":"TypeResolver.TypeExporter.html"},{"type":"function","title":"TypeResolver.TypeExporter.export_types/2","doc":"","ref":"TypeResolver.TypeExporter.html#export_types/2"},{"type":"module","title":"TypeResolver.Types","doc":"This modules defines a struct based representation of spec types.","ref":"TypeResolver.Types.html"},{"type":"type","title":"TypeResolver.Types.inner_map_t/0","doc":"","ref":"TypeResolver.Types.html#t:inner_map_t/0"},{"type":"type","title":"TypeResolver.Types.t/0","doc":"","ref":"TypeResolver.Types.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.AnyT","doc":"Representation of the spec of an any-type, e.g. `any()`","ref":"TypeResolver.Types.AnyT.html"},{"type":"type","title":"TypeResolver.Types.AnyT.t/0","doc":"","ref":"TypeResolver.Types.AnyT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.AtomL","doc":"Representation of the spec of an atom-literal, e.g. `:hello`","ref":"TypeResolver.Types.AtomL.html"},{"type":"type","title":"TypeResolver.Types.AtomL.t/0","doc":"","ref":"TypeResolver.Types.AtomL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.AtomT","doc":"Representation of the spec of an atom-type, e.g. `atom()`","ref":"TypeResolver.Types.AtomT.html"},{"type":"type","title":"TypeResolver.Types.AtomT.t/0","doc":"","ref":"TypeResolver.Types.AtomT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.BinaryT","doc":"Representation of the spec of a binary-type, e.g. `binary()`","ref":"TypeResolver.Types.BinaryT.html"},{"type":"type","title":"TypeResolver.Types.BinaryT.t/0","doc":"","ref":"TypeResolver.Types.BinaryT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.BitstringWithUnitL","doc":"Representation of the spec of an bitstring-literal with unit, e.g. `<<_::_*12>>`\n\nIt consists of the following:\n- the unit of the bitstring","ref":"TypeResolver.Types.BitstringWithUnitL.html"},{"type":"type","title":"TypeResolver.Types.BitstringWithUnitL.t/0","doc":"","ref":"TypeResolver.Types.BitstringWithUnitL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.BooleanL","doc":"Representation of the spec of a boolean-literal, e.g. `true`\n\nIt consists of the following:\n- the value of the literal, either `true` or `false`","ref":"TypeResolver.Types.BooleanL.html"},{"type":"type","title":"TypeResolver.Types.BooleanL.t/0","doc":"","ref":"TypeResolver.Types.BooleanL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.BooleanT","doc":"Representation of the spec of a boolean-type, e.g. `boolean()`","ref":"TypeResolver.Types.BooleanT.html"},{"type":"type","title":"TypeResolver.Types.BooleanT.t/0","doc":"","ref":"TypeResolver.Types.BooleanT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.EmptyBitstringL","doc":"Representation of the spec of an empty bitstring-literal, e.g. `<<>>`","ref":"TypeResolver.Types.EmptyBitstringL.html"},{"type":"type","title":"TypeResolver.Types.EmptyBitstringL.t/0","doc":"","ref":"TypeResolver.Types.EmptyBitstringL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.EmptyListL","doc":"Representation of the spec of an empty list-literal, e.g. `[]`","ref":"TypeResolver.Types.EmptyListL.html"},{"type":"type","title":"TypeResolver.Types.EmptyListL.t/0","doc":"","ref":"TypeResolver.Types.EmptyListL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.EmptyMapL","doc":"Representation of the spec of an arbitrary empty map-literal, e.g. `%{}`","ref":"TypeResolver.Types.EmptyMapL.html"},{"type":"type","title":"TypeResolver.Types.EmptyMapL.t/0","doc":"","ref":"TypeResolver.Types.EmptyMapL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.FloatT","doc":"Representation of the spec of a float-type, e.g. `float()`","ref":"TypeResolver.Types.FloatT.html"},{"type":"type","title":"TypeResolver.Types.FloatT.t/0","doc":"","ref":"TypeResolver.Types.FloatT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.FunctionL","doc":"Representation of the spec of an function-literal, e.g. `(binary(), integer()) -> binary()`\n\nIt consists of the following:\n\n- the arity of the function","ref":"TypeResolver.Types.FunctionL.html"},{"type":"type","title":"TypeResolver.Types.FunctionL.t/0","doc":"","ref":"TypeResolver.Types.FunctionL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.IntegerL","doc":"Representation of the spec of an integer-literal, e.g. `12`","ref":"TypeResolver.Types.IntegerL.html"},{"type":"type","title":"TypeResolver.Types.IntegerL.t/0","doc":"","ref":"TypeResolver.Types.IntegerL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.IntegerT","doc":"Representation of the spec of a integer-type, e.g. `integer()`","ref":"TypeResolver.Types.IntegerT.html"},{"type":"type","title":"TypeResolver.Types.IntegerT.t/0","doc":"","ref":"TypeResolver.Types.IntegerT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.ListT","doc":"Representation of the spec of a list-type, e.g. `list(integer())`\n\nIt consists of the following:\n- the type of the list elements","ref":"TypeResolver.Types.ListT.html"},{"type":"type","title":"TypeResolver.Types.ListT.t/0","doc":"","ref":"TypeResolver.Types.ListT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.MapAnyT","doc":"Representation of the spec of an arbitrary map-type, e.g. `map()`","ref":"TypeResolver.Types.MapAnyT.html"},{"type":"type","title":"TypeResolver.Types.MapAnyT.t/0","doc":"","ref":"TypeResolver.Types.MapAnyT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.MapFieldAssocL","doc":"Representation of the spec of an optional field in a map-literal, e.g. `%{:a => integer()}`\n\nIt consists of the following:\n- a key\n- a value","ref":"TypeResolver.Types.MapFieldAssocL.html"},{"type":"type","title":"TypeResolver.Types.MapFieldAssocL.t/0","doc":"","ref":"TypeResolver.Types.MapFieldAssocL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.MapFieldExactL","doc":"Representation of the spec of a required field in a map-literal, e.g. `%{required(:a) => integer()}`\n\nIt consists of the following:\n- a key\n- a value","ref":"TypeResolver.Types.MapFieldExactL.html"},{"type":"type","title":"TypeResolver.Types.MapFieldExactL.t/0","doc":"","ref":"TypeResolver.Types.MapFieldExactL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.MapL","doc":"Representation of the spec of a map-literal, e.g. `%{a: integer(), b: binary()}`\n\nIt consists of the following:\n- a list of types of inner elements","ref":"TypeResolver.Types.MapL.html"},{"type":"type","title":"TypeResolver.Types.MapL.t/0","doc":"","ref":"TypeResolver.Types.MapL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.MaybeImproperListT","doc":"Representation of the spec of a maybe improper list-type, e.g. `maybe_improper_list(integer() integer())`\n\nIt consists of the following:\n- the type of the non empty list's elements\n- the termination type","ref":"TypeResolver.Types.MaybeImproperListT.html"},{"type":"type","title":"TypeResolver.Types.MaybeImproperListT.t/0","doc":"","ref":"TypeResolver.Types.MaybeImproperListT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NegIntegerT","doc":"Representation of the spec of a negative integer-type, e.g. `neg_integer()`","ref":"TypeResolver.Types.NegIntegerT.html"},{"type":"type","title":"TypeResolver.Types.NegIntegerT.t/0","doc":"","ref":"TypeResolver.Types.NegIntegerT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NilL","doc":"Representation of the spec of a nil-literal, e.g. `nil`","ref":"TypeResolver.Types.NilL.html"},{"type":"type","title":"TypeResolver.Types.NilL.t/0","doc":"","ref":"TypeResolver.Types.NilL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NonNegIntegerT","doc":"Representation of the spec of a non negative integer-type, e.g. `non_neg_integer()`","ref":"TypeResolver.Types.NonNegIntegerT.html"},{"type":"type","title":"TypeResolver.Types.NonNegIntegerT.t/0","doc":"","ref":"TypeResolver.Types.NonNegIntegerT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NoneT","doc":"Representation of the spec of a none-type, e.g. `none()`","ref":"TypeResolver.Types.NoneT.html"},{"type":"type","title":"TypeResolver.Types.NoneT.t/0","doc":"","ref":"TypeResolver.Types.NoneT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NonemptyImproperListT","doc":"Representation of the spec of a maybe improper list-type, e.g. `non_empty_improper_list(integer() integer())`\n\nIt consists of the following:\n- the type of the non empty list's elements\n- the termination type","ref":"TypeResolver.Types.NonemptyImproperListT.html"},{"type":"type","title":"TypeResolver.Types.NonemptyImproperListT.t/0","doc":"","ref":"TypeResolver.Types.NonemptyImproperListT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NonemptyListT","doc":"Representation of the spec of a non empty list-type, e.g. `nonempty_list()` or `nonempty_list(integer())`\n\nIt consists of the following:\n- the type of the non empty list's elements","ref":"TypeResolver.Types.NonemptyListT.html"},{"type":"type","title":"TypeResolver.Types.NonemptyListT.t/0","doc":"","ref":"TypeResolver.Types.NonemptyListT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.NonemptyMaybeImproperListT","doc":"Representation of the spec of a non empty maybe improper list-type, e.g. `non_empty_maybe_improper_list(integer() integer())`\n\nIt consists of the following:\n- the type of the non empty list's elements\n- the termination type","ref":"TypeResolver.Types.NonemptyMaybeImproperListT.html"},{"type":"type","title":"TypeResolver.Types.NonemptyMaybeImproperListT.t/0","doc":"","ref":"TypeResolver.Types.NonemptyMaybeImproperListT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.PidT","doc":"Representation of the spec of a pid-type, e.g. `pid()`","ref":"TypeResolver.Types.PidT.html"},{"type":"type","title":"TypeResolver.Types.PidT.t/0","doc":"","ref":"TypeResolver.Types.PidT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.PortT","doc":"Representation of the spec of a port-type, e.g. `port()`","ref":"TypeResolver.Types.PortT.html"},{"type":"type","title":"TypeResolver.Types.PortT.t/0","doc":"","ref":"TypeResolver.Types.PortT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.PosIntegerT","doc":"Representation of the spec of a positive integer-type, e.g. `pos_integer()`","ref":"TypeResolver.Types.PosIntegerT.html"},{"type":"type","title":"TypeResolver.Types.PosIntegerT.t/0","doc":"","ref":"TypeResolver.Types.PosIntegerT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.RangeL","doc":"Representation of the spec of a range-literal, e.g. `1..12`\n\nIt consists of the following:\n\n- the lower limit of the range\n- the upper limit of the range","ref":"TypeResolver.Types.RangeL.html"},{"type":"type","title":"TypeResolver.Types.RangeL.t/0","doc":"","ref":"TypeResolver.Types.RangeL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.ReferenceT","doc":"Representation of the spec of a reference-type, e.g. `reference()`","ref":"TypeResolver.Types.ReferenceT.html"},{"type":"type","title":"TypeResolver.Types.ReferenceT.t/0","doc":"","ref":"TypeResolver.Types.ReferenceT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.SizedBitstringL","doc":"Representation of the spec of an sized bitstring-literal, e.g. `<<_::12>>`\n\nIt consists of the following:\n- the size of the bitstring","ref":"TypeResolver.Types.SizedBitstringL.html"},{"type":"type","title":"TypeResolver.Types.SizedBitstringL.t/0","doc":"","ref":"TypeResolver.Types.SizedBitstringL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.SizedBitstringWithUnitL","doc":"Representation of the spec of an sized bitstring-literal with unit, e.g. `<<_::12, _::_*12>>`\n\nIt consists of the following:\n- the unit of the bitstring\n- the size of the bitstring","ref":"TypeResolver.Types.SizedBitstringWithUnitL.html"},{"type":"type","title":"TypeResolver.Types.SizedBitstringWithUnitL.t/0","doc":"","ref":"TypeResolver.Types.SizedBitstringWithUnitL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.StructL","doc":"Representation of the spec of an struct literal, e.g. `%MyStruct{}`\n\nIt consists of the following:\n\n- the module, the struct is defined in","ref":"TypeResolver.Types.StructL.html"},{"type":"type","title":"TypeResolver.Types.StructL.t/0","doc":"","ref":"TypeResolver.Types.StructL.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.TupleAnyT","doc":"Representation of the spec of an arbitrary tuple-type, e.g. `tuple()`","ref":"TypeResolver.Types.TupleAnyT.html"},{"type":"type","title":"TypeResolver.Types.TupleAnyT.t/0","doc":"","ref":"TypeResolver.Types.TupleAnyT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.TupleT","doc":"Representation of the spec of a reference-type, e.g. `{atom(), integer()}`\n\nIt consists of the following:\n- a list of the types of the tuple's elements","ref":"TypeResolver.Types.TupleT.html"},{"type":"type","title":"TypeResolver.Types.TupleT.t/0","doc":"","ref":"TypeResolver.Types.TupleT.html#t:t/0"},{"type":"module","title":"TypeResolver.Types.UnionT","doc":"Representation of the spec of an union-type, e.g. `atom() | integer()`\n\nIt consists of the following:\n- a list of the types of the union's elements","ref":"TypeResolver.Types.UnionT.html"},{"type":"type","title":"TypeResolver.Types.UnionT.t/0","doc":"","ref":"TypeResolver.Types.UnionT.html#t:t/0"}],"content_type":"text/markdown"}